==> xmpp-extensions-common-0.8.0-sources.jar: rocks/xmpp/extensions/rpc/model/NumericBoolean.java <==
/*
 * The MIT License (MIT)
 *
 * Copyright (c) 2014-2018 Christian Schudt
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */

package rocks.xmpp.extensions.rpc.model;

import javax.xml.bind.annotation.XmlValue;

/**
 * @author Christian Schudt
 */
final class NumericBoolean {
    @XmlValue
    private final Integer value;

    private NumericBoolean() {
        this(false);
    }

    NumericBoolean(boolean b) {
        this.value = b ? 1 : 0;
    }

    final Integer getValue() {
        return value;
    }

    final boolean getAsBoolean() {
        return value != null && value == 1;
    }

    @Override
    public final String toString() {
        return value == 1 ? Boolean.TRUE.toString() : Boolean.FALSE.toString();
    }
}

==> xmpp-extensions-common-0.9.0-sources.jar: rocks/xmpp/extensions/rpc/model/NumericBoolean.java <==
/*
 * The MIT License (MIT)
 *
 * Copyright (c) 2014-2018 Christian Schudt
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */

package rocks.xmpp.extensions.rpc.model;

import java.util.Objects;
import javax.xml.bind.annotation.XmlValue;

/**
 * @author Christian Schudt
 */
final class NumericBoolean {

    @XmlValue
    private final Integer value;

    private NumericBoolean() {
        this(false);
    }

    NumericBoolean(boolean b) {
        this.value = b ? 1 : 0;
    }

    final Integer getValue() {
        return value;
    }

    final boolean getAsBoolean() {
        return value != null && value == 1;
    }

    @Override
    public final boolean equals(Object o) {
        if (o == this) {
            return true;
        }
        if (!(o instanceof NumericBoolean)) {
            return false;
        }
        NumericBoolean other = (NumericBoolean) o;

        return Objects.equals(value, other.value);
    }

    @Override
    public final int hashCode() {
        return Objects.hash(value);
    }

    @Override
    public final String toString() {
        return value == 1 ? Boolean.TRUE.toString() : Boolean.FALSE.toString();
    }
}
